==> dde-shell_0.0.23.tar.xz: BUILD/panels/osd/default/translations/org.deepin.ds.osd.default_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>WLAN ligada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>WLAN desligada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock ativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico ligado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>Touchpad ligado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>Touchpad desligado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>Modo avião ativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>Modo avião desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>Potência balanceada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>Economia de energia</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>Alto desempenho</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>Efeito de janela ativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>Efeitos de janela desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>Falha ao ativar os efeitos de janela</translation>
    </message>
</context>
</TS>

==> dde-shell_0.0.24.tar.xz: BUILD/panels/osd/default/translations/org.deepin.ds.osd.default_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>WLAN ligada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>WLAN desligada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock ativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico ligado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>Touchpad ligado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>Touchpad desligado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>Modo avião ativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>Modo avião desativado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>Ativar mudo</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>Desativar mudo</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>Potência balanceada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>Economia de energia</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>Alto desempenho</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>Efeitos visuais ativados</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>Efeitos visuais desativados</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>Falha ao ativar os efeitos visuais</translation>
    </message>
</context>
</TS>
